@@ -1,3 +1,10 @@
+# Copyright 2020 The Caer Authors. All Rights Reserved.
+#
+# Licensed under the MIT License (see LICENSE);
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at <https://opensource.org/licenses/MIT>
+#
+# ==============================================================================
 
 #pylint: disable=bare-except,protected-access,c-extension-no-member
 
@@ -40,13 +47,9 @@ def _deprecate_positional_args(f):
             return f(*args, **kwargs)
 
         # extra_args > 0
-        args_msg = ['{}={}'.format(name, arg)
-                    for name, arg in zip(kwonly_args[:extra_args],
+        args_msg = [f'{name}={arg}' for name, arg in zip(kwonly_args[:extra_args],
                                          args[-extra_args:])]
-        warnings.warn("Pass {} as keyword args. From version 0.25 "
-                      "passing these as positional arguments will "
-                      "result in an error".format(", ".join(args_msg)),
-                      FutureWarning)
+        warnings.warn(f"Pass {'', ''.join(args_msg)} as keyword args. From version 0.25,                 passing these as positional arguments will result in an error", FutureWarning)
         kwargs.update(zip(sig.parameters, args))
         return f(**kwargs)
     return inner_f
@@ -192,8 +195,7 @@ def check_array(array, *,
     #     array = array.astype(dtype)
 
     if force_all_finite not in (True, False, 'allow-nan'):
-        raise ValueError('force_all_finite should be a bool or "allow-nan"'
-                         '. Got {!r} instead'.format(force_all_finite))
+        raise ValueError(f"force_all_finite should be a bool or 'allow-nan'. Got {force_all_finite} instead")
 
     if estimator is not None:
         if isinstance(estimator, str):
@@ -260,17 +262,17 @@ def check_array(array, *,
             # If input is scalar raise error
             if array.ndim == 0:
                 raise ValueError(
-                    "Expected 2D array, got scalar array instead:\narray={}.\n"
+                    f"Expected 2D array, got scalar array instead:\narray={array}.\n"
                     "Reshape your data either using array.reshape(-1, 1) if "
                     "your data has a single feature or array.reshape(1, -1) "
-                    "if it contains a single sample.".format(array))
+                    "if it contains a single sample.")
             # If input is 1D raise error
             if array.ndim == 1:
                 raise ValueError(
-                    "Expected 2D array, got 1D array instead:\narray={}.\n"
+                    f"Expected 2D array, got 1D array instead:\narray={array}.\n"
                     "Reshape your data either using array.reshape(-1, 1) if "
                     "your data has a single feature or array.reshape(1, -1) "
-                    "if it contains a single sample.".format(array))
+                    "if it contains a single sample.")
 
         # in the future np.flexible dtypes will be handled like object dtypes
         if dtype_numeric and np.issubdtype(array.dtype, np.flexible):
