@@ -244,7 +244,7 @@ def _safe_indexing(X, indices, *, axis=0):
     if axis not in (0, 1):
         raise ValueError(
             "'axis' should be either 0 (to index rows) or 1 (to index "
-            " column). Got {} instead.".format(axis)
+            f" column). Got {axis} instead."
         )
 
     indices_dtype = _determine_key_type(indices)
@@ -258,7 +258,7 @@ def _safe_indexing(X, indices, *, axis=0):
         raise ValueError(
             "'X' should be a 2D NumPy array, 2D sparse matrix or pandas "
             "dataframe when indexing the columns (i.e. 'axis=1'). "
-            "Got {} instead with {} dimension(s).".format(type(X), X.ndim)
+            f"Got {type(X)} instead with {X.ndim} dimension(s)."
         )
 
     if axis == 1 and indices_dtype == 'str' and not hasattr(X, 'loc'):
@@ -288,27 +288,27 @@ def _validate_shuffle_split(n_samples, test_size, train_size,
 
     if (test_size_type == 'i' and (test_size >= n_samples or test_size <= 0)
        or test_size_type == 'f' and (test_size <= 0 or test_size >= 1)):
-        raise ValueError('test_size={0} should be either positive and smaller'
-                         ' than the number of samples {1} or a float in the '
-                         '(0, 1) range'.format(test_size, n_samples))
+        raise ValueError(f'test_size={test_size} should be either positive and smaller'
+                         f' than the number of samples {n_samples} or a float in the '
+                         '(0, 1) range')
 
     if (train_size_type == 'i' and (train_size >= n_samples or train_size <= 0)
        or train_size_type == 'f' and (train_size <= 0 or train_size >= 1)):
-        raise ValueError('train_size={0} should be either positive and smaller'
-                         ' than the number of samples {1} or a float in the '
-                         '(0, 1) range'.format(train_size, n_samples))
+        raise ValueError(f'train_size={train_size} should be either positive and smaller'
+                         f' than the number of samples {n_samples} or a float in the '
+                         '(0, 1) range')
 
     if train_size is not None and train_size_type not in ('i', 'f'):
-        raise ValueError("Invalid value for train_size: {}".format(train_size))
+        raise ValueError(f"Invalid value for train_size: {train_size}")
     if test_size is not None and test_size_type not in ('i', 'f'):
-        raise ValueError("Invalid value for test_size: {}".format(test_size))
+        raise ValueError(f"Invalid value for test_size: {test_size}")
 
     if (train_size_type == 'f' and test_size_type == 'f' and
             train_size + test_size > 1):
         raise ValueError(
-            'The sum of test_size and train_size = {}, should be in the (0, 1)'
+            f'The sum of test_size and train_size = {train_size + test_size}, should be in the (0, 1)'
             ' range. Reduce test_size and/or train_size.'
-            .format(train_size + test_size))
+            )
 
     if test_size_type == 'f':
         n_test = ceil(test_size * n_samples)
@@ -335,10 +335,9 @@ def _validate_shuffle_split(n_samples, test_size, train_size,
 
     if n_train == 0:
         raise ValueError(
-            'With n_samples={}, test_size={} and train_size={}, the '
+            f'With n_samples={n_samples}, test_size={test_size} and train_size={train_size}, the '
             'resulting train set will be empty. Adjust any of the '
-            'aforementioned parameters.'.format(n_samples, test_size,
-                                                train_size)
+            'aforementioned parameters.'
         )
 
     return n_train, n_test
\ No newline at end of file
