@@ -1,21 +1,25 @@
-# Author: Jason Dsouza
-# Github: http://www.github.com/jasmcaus
+# Copyright 2020 The Caer Authors. All Rights Reserved.
+#
+# Licensed under the MIT License (see LICENSE);
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at <https://opensource.org/licenses/MIT>
+#
+# ==============================================================================
 
-# Importing the necessary packages
-import sys
-sys.path.append('..')
-
-import os
 import random
 import time
-import numpy as np
-from .utils import readImg, saveNumpy, get_classes_from_dir
-from .preprocessing import MeanProcess, _check_mean_sub_values
+
+from .utilities import saveNumpy, get_classes_from_dir, to_array, load
+from .io import imread
+from .preprocessing import MeanProcess
+from ._checks import _check_target_size, _check_mean_sub_values
+from .path import listdir, minijoin, exists, list_images
+
 
 def preprocess_from_dir(DIR, 
                         classes=None, 
-                        channels=1, 
                         IMG_SIZE=(224,224), 
+                        channels=3, 
                         per_class_size=None, 
                         normalize_train=False, 
                         mean_subtraction=None, 
@@ -25,32 +29,35 @@ def preprocess_from_dir(DIR,
                         verbose=1):
     """
     Reads Images in base directory DIR using 'classes' (computed from sub directories )
-    @param DIR: Directory 
-    @param classes --> A list of folder names within `DIR`
-    @param channels: Number of channels each image will be processed to (default: 1)
-    :param per_class_size: Intended size of the each class to be preprocessed
-    :param normalize_train: Whether to normalize each image to between [0,1]
-    :param mean_subtraction: Whether mean subtraction should be applied (Tuple)
-    :param isShuffle: Shuffle the training set
-    :param save_data: If True, saves the training set as a .npy or .npz file based on destination_filename
-    :param destination_filename: if save_data is True, the train set will be saved as the filename specified
-    :param verbose: Integer either 0 (verbosity off) or 1 (verbosity on). Displays the progress to the terminal as preprocessing continues. Default = 1
+    Arguments:
+        :param DIR: Base directory 
+        :param classes: A list of folder names within `DIR`. Automatically inferred from DIR if not provided
+        :param IMG_SIZE: Image Size tuple of size 2 (width, height)
+        :param channels: Number of channels each image will be processed to (default: 3)
+        :param per_class_size: Intended size of the each class to be preprocessed
+        :param normalize_train: Whether to normalize each image to between [0,1]
+        :param mean_subtraction: Whether mean subtraction should be applied (Tuple)
+        :param isShuffle: Shuffle the training set
+        :param save_data: If True, saves the training set as a .npy or .npz file based on destination_filename
+        :param destination_filename: if save_data is True, the train set will be saved as the filename specified
+        :param verbose: Integer either 0 (verbosity off) or 1 (verbosity on). Displays the progress to the terminal as preprocessing continues. Default = 1
     
-    :return data: Image Pixel Values with corresponding labels (float32)
-    :return classes: ONLY if `classes=None`
-    Saves the above variables as .npy files if `save_data = True`
+    Returns
+        :return data: Image Pixel Values with corresponding labels (float32)
+        :return classes: ONLY if `classes=None`
+        Saves the above variables as .npy files if `save_data = True`
     """
     return_classes_flag = False
     data = [] 
 
-    if not os.path.exists(DIR):
-        raise ValueError('[ERROR] The specified directory does not exist')
+    if not exists(DIR):
+        raise ValueError('The specified directory does not exist')
 
     if IMG_SIZE is None:
-        raise ValueError('[ERROR] IMG_SIZE must be specified')
+        raise ValueError('IMG_SIZE must be specified')
 
-    if type(IMG_SIZE) is not tuple or len(IMG_SIZE) != 2:
-        raise ValueError('[ERROR] IMG_SIZE must be a tuple of size 2 (width,height)')
+    if not isinstance(IMG_SIZE, tuple) or len(IMG_SIZE) != 2:
+        raise ValueError('IMG_SIZE must be a tuple of size 2 (width,height)')
 
     if verbose in [0,1]:
         if verbose == 0:
@@ -58,34 +65,35 @@ def preprocess_from_dir(DIR,
         else:
             display_count = True
     
-    if verbose not in [0,1]:
-        raise ValueError('[ERROR] verbose flag must be either 1 (display progress to terminal) or 0 otherwise')
+    else:
+        raise ValueError('verbose flag must be either 1 (display progress to terminal) or 0 otherwise')
 
-    if type(save_data) is not bool:
-        raise ValueError('[ERROR] save_data is a boolean (True/False)')
+    if not isinstance(save_data, bool):
+        raise ValueError('save_data must be a boolean (True/False)')
 
     if classes is None:
         return_classes_flag = True
 
-    if classes is not None and type(classes) is not list:
-        raise ValueError('[ERROR] "classes" must be a list')
+    else:
+        if not isinstance(classes, list):
+            raise ValueError('"classes" must be a list')
 
     if save_data:
         if destination_filename is None:
-            raise ValueError('[ERROR] Specify a destination file name')
+            raise ValueError('Specify a destination file name')
 
         elif not ('.npy' in destination_filename or '.npz' in destination_filename):
-            raise ValueError('[ERROR] Specify the correct numpy destination file extension (.npy or .npz)')
+            raise ValueError('Specify the correct numpy destination file extension (.npy or .npz)')
     
     if not save_data and destination_filename is not None:
         destination_filename = None
     
 
     # Loading from Numpy Files
-    if destination_filename is not None and os.path.exists(destination_filename):
-        since = time.time()
+    if destination_filename is not None and exists(destination_filename):
         print('[INFO] Loading from Numpy Files')
-        data = np.load(destination_filename, allow_pickle=True)
+        since = time.time()
+        data = load(destination_filename, allow_pickle=True)
         end = time.time()
         print('----------------------------------------------')
         print('[INFO] Loaded in {:.0f}s from Numpy Files'.format(end-since))
@@ -94,33 +102,39 @@ def preprocess_from_dir(DIR,
 
     # Extracting image data and adding to `data`
     else:
-        since_preprocess = time.time()
         if destination_filename is not None:
-            print(f'[INFO] Could not find {destination_filename}. Generating the Image Files')
+            print(f'[INFO] Could not find {destination_filename}. Generating the training data')
         else:
-            print('[INFO] Could not find a file to load from. Generating Image Files')
+            print('[INFO] Could not find a file to load from. Generating the training data')
         print('----------------------------------------------')
+        # Starting timer
+        since_preprocess = time.time()
 
         if classes is None:
             classes = get_classes_from_dir(DIR)
+            # Removing false folders
+            classes = _check_for_false_folders(DIR, classes)
+
 
         if per_class_size is None:
-            per_class_size = len(os.listdir(os.path.join(DIR, classes[0])))
+            per_class_size = len(listdir(minijoin(DIR, classes[0]), verbose=0))
 
         if mean_subtraction is not None:
             # Checking if 'mean_subtraction' values are valid. Returns boolean value
             subtract_mean = _check_mean_sub_values(mean_subtraction, channels)
 
         for item in classes:
-            class_path = os.path.join(DIR, item)
+            class_path = minijoin(DIR, item)
             class_label = classes.index(item)
             count = 0 
-            for image in os.listdir(class_path):
-                if count != per_class_size:
-                    image_path = os.path.join(class_path, image)
+            img_list = list_images(class_path, use_fullpath=True, verbose=0)
 
-                    # Returns the resized image
-                    img = readImg(image_path, resized_img_size=IMG_SIZE, channels=channels)
+            for image_path in img_list:
+                if count != per_class_size:
+                    # image_path = minijoin(class_path, image)
+
+                    # Returns the resized image (ignoring aspect ratio since it isn't relevant for Deep Computer Vision models)
+                    img = imread(image_path, target_size=IMG_SIZE, channels=channels)
                     if img is None:
                         continue
 
@@ -148,7 +162,7 @@ def preprocess_from_dir(DIR,
             data = shuffle(data)
 
         # Converting to Numpy
-        data = np.array(data)
+        data = to_array(data)
 
         # Saves the Data set as a .npy file
         if save_data:
@@ -158,8 +172,8 @@ def preprocess_from_dir(DIR,
             elif destination_filename.endswith('.npz'):
                 print('[INFO] Saving as .npz file')
             
-            since = time.time()
             # Saving
+            since = time.time()
             saveNumpy(destination_filename, data)
             end = time.time()
             
@@ -169,9 +183,9 @@ def preprocess_from_dir(DIR,
 
         #Returns Training Set
         end_preprocess = time.time()
-        time_elapsed_preprocess = end_preprocess-since_preprocess
+        time_elapsed_preprocess = end_preprocess - since_preprocess
         print('----------------------------------------------')
-        print('[INFO] {} files preprocessed! Took {:.0f}m {:.0f}s'.format(count, time_elapsed_preprocess // 60, time_elapsed_preprocess % 60))
+        print('[INFO] {} files preprocessed! Took {:.0f}m {:.0f}s'.format(len(data), time_elapsed_preprocess // 60, time_elapsed_preprocess % 60))
 
         if return_classes_flag:
             return data, classes
@@ -183,6 +197,19 @@ def _printTotal(count, category):
     print(f'{count} - {category}')
 
 
+def _check_for_false_folders(base_dir, classes):
+    if len(classes) == 0:
+        return []
+    else:
+        g = []
+        for i in classes:
+            path = minijoin(base_dir, i)
+            if list_images(path, include_subdirs=False, verbose=0) is not None:
+                g.append(i)
+    
+    return g
+
+
 def shuffle(data):
     """
     Shuffles the Array
@@ -198,35 +225,26 @@ def sep_train(data, IMG_SIZE, channels=1):
     #     x.append(feature)
     #     y.append(label)
     
-    if IMG_SIZE is None:
-        raise ValueError('[ERROR] IMG_SIZE not defined')
+    _ = _check_target_size(IMG_SIZE)
 
-    if type(IMG_SIZE) is not tuple or len(IMG_SIZE) != 2:
-        raise ValueError('[ERROR] IMG_SIZE must be a tuple of size 2')
+    x = [i[0] for i in data]
+    y = [i[1] for i in data]
 
-    else:
-        x = [i[0] for i in data]
-        y = [i[1] for i in data]
+    # Without reshaping, X.shape --> (no. of images, IMG_SIZE, IMG_SIZE)
+    # On reshaping, X.shape --> (no. of images, IMG_SIZE, IMG_SIZE, channels)
 
-        # Without reshaping, X.shape --> (no. of images, IMG_SIZE, IMG_SIZE)
-        # On reshaping, X.shape --> (no. of images, IMG_SIZE, IMG_SIZE,channels)
+    # Converting to Numpy + Reshaping X
+    x = reshape(x, IMG_SIZE, channels)
+    y = to_array(y)
 
-        # Converting to Numpy + Reshaping X
-        x = reshape(x, IMG_SIZE, channels)
-        y = np.array(y)
-
-        return x, y
+    return x, y
 
 
 def reshape(x, IMG_SIZE, channels):
-    if IMG_SIZE is None:
-        raise ValueError('[ERROR] IMG_SIZE not defined')
-
-    if type(IMG_SIZE) is not tuple or len(IMG_SIZE) != 2:
-        raise ValueError('[ERROR] IMG_SIZE must be a tuple of size 2')
+    _ = _check_target_size(IMG_SIZE)
 
     width, height = IMG_SIZE[:2]
-    return np.array(x).reshape(-1, width, height, channels)
+    return to_array(x).reshape(-1, width, height, channels)
 
 
 def normalize(x, dtype='float32'):
@@ -239,3 +257,12 @@ def normalize(x, dtype='float32'):
     # Converting to float32 and normalizing (float32 saves memory)
     x = x.astype(dtype) / 255
     return x
+
+
+__all__ = [
+    'preprocess_from_dir',
+    'sep_train',
+    'shuffle',
+    'reshape',
+    'normalize'
+]
\ No newline at end of file
