@@ -1,11 +1,19 @@
-# Author: Jason Dsouza
-# Github: http://www.github.com/jasmcaus
+# Copyright 2020 The Caer Authors. All Rights Reserved.
+#
+# Licensed under the MIT License (see LICENSE);
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at <https://opensource.org/licenses/MIT>
+#
+# ==============================================================================
 
 #pylint:disable=pointless-string-statement
 
-# Importing the necessary packages
-import cv2 as cv
-import os 
+from .._checks import _check_mean_sub_values
+from ..path import exists, list_images
+from ..io import imread 
+from ..opencv import mean, merge, split
+from ..utilities import npmean
+
 
 """
     Important notes:
@@ -22,7 +30,7 @@ class MeanProcess:
                 self.gMean = mean_sub_values[1]
                 self.bMean = mean_sub_values[2]
             else:
-                self.mean = mean_sub_values
+                self.bgrMean = mean_sub_values
 
     def mean_preprocess(self, image, channels):
         """
@@ -31,18 +39,18 @@ class MeanProcess:
         """
 
         if channels == 3:
-            (b,g,r) = cv.split(image.astype('float32'))[:3]
+            b, g, r = split(image.astype('float32'))[:3]
 
             # Subtracting the mean
             r -= self.rMean
-            b -= self.bMean
             g -= self.gMean
+            b -= self.bMean
 
             # Merging 
-            return cv.merge([b,g,r])
+            return merge([b,g,r])
         
         if channels == 1:
-            image -= self.mean
+            image -= self.bgrMean
             return image
             
 
@@ -51,34 +59,40 @@ def compute_mean_from_dir(DIR, channels, per_channel_subtraction=True):
         Computes mean per channel
         Mean must be computed ONLY on the train set
     """
-    if os.path.exists(DIR) is False:
-        raise ValueError('The specified directory does not exist', DIR)
+    if exists(DIR) is False:
+        raise ValueError('The specified directory does not exist')
+    
+    image_list = list_images(DIR, include_subdirs=True, use_fullpath=True, verbose=0)
+
+    if len(image_list) == 0:
+        raise ValueError(f'No images found at {DIR}')
 
     if channels == 3:
-        rMean, gMean, bMean = 0,0,0
+        rMean, gMean, bMean = 0, 0, 0
     if channels == 1:
-        mean = 0
+        bgrMean = 0
+
     count = 0
 
-    for root, _, files in os.walk(DIR):
-        for file in files:
-            if file.endswith('.png') or file.endswith('.jpg'):
-                count += 1
-                filepath = root + os.sep + file
-                img = cv.imread(filepath)
-                if channels == 3:
-                    b,g,r = cv.mean(img.astype('float32'))[:3]
-                    rMean += r
-                    bMean += b
-                    gMean += g
-                if channels == 1:
-                    mean += cv.mean(img.astype('float32'))[0]
+    for img_filepath in image_list:
+        count += 1
+        img = imread(img_filepath, rgb=False)
+
+        if channels == 3:
+            b, g, r = mean(img.astype('float32'))[:3]
+            rMean += r
+            bMean += b
+            gMean += g
+
+        if channels == 1:
+            bgrMean += npmean(img.astype('float32'))
 
     # Computing average mean
     if channels == 3:
         rMean /= count
         bMean /= count 
         gMean /= count
+
         if per_channel_subtraction:
             return rMean, bMean, gMean
         else:
@@ -86,8 +100,8 @@ def compute_mean_from_dir(DIR, channels, per_channel_subtraction=True):
             return mean_of_means, mean_of_means, mean_of_means
 
     if channels == 1:
-        mean /= count
-        return tuple([mean])
+        bgrMean /= count
+        return tuple([bgrMean])
 
 
 def compute_mean(data, channels, per_channel_subtraction=True):
@@ -96,26 +110,27 @@ def compute_mean(data, channels, per_channel_subtraction=True):
         Train should not be normalized
     """
     if len(data) == 0:
-        raise ValueError('[ERROR] Dataset is empty')
+        raise ValueError('Dataset is empty')
     
-    if type(data) is not list:
-        raise ValueError('[ERROR] Dataset must be a list of size=number of images and shape=image shape')
+    if not isinstance(data, list):
+        raise ValueError('Dataset must be a list of size=number of images and shape=image shape')
 
     if channels == 3:
         rMean, gMean, bMean = 0,0,0
     if channels == 1:
-        mean = 0
+        bgrMean = 0
+
     count = 0
 
     for img in data:
         count += 1
         if channels == 3:
-            b,g,r = cv.mean(img.astype('float32'))[:3]
+            b, g, r = mean(img.astype('float32'))[:3]
             rMean += r
-            bMean += b
             gMean += g
+            bMean += b
         if channels == 1:
-            mean += cv.mean(img.astype('float32'))[0]
+            bgrMean += npmean(img.astype('float32'))
 
     # Computing average mean
     if channels == 3:
@@ -129,8 +144,8 @@ def compute_mean(data, channels, per_channel_subtraction=True):
             return mean_of_means, mean_of_means, mean_of_means
 
     if channels == 1:
-        mean /= count
-        return tuple([mean])
+        bgrMean /= count
+        return tuple([bgrMean])
 
 
 def subtract_mean(data, channels, mean_sub_values):
@@ -142,42 +157,19 @@ def subtract_mean(data, channels, mean_sub_values):
     mean_process = MeanProcess(mean_sub_values, channels)
 
     if len(data) == 0:
-        raise ValueError('[ERROR] Dataset is empty')
+        raise ValueError('Dataset is empty')
     
-    if type(data) is not list:
-        raise ValueError('[ERROR] Dataset must be a list of size=number of images and shape=image shape')
+    if not isinstance(data, list):
+        raise ValueError('Dataset must be a list of size = number of images and shape = image shape')
 
     data = [mean_process.mean_preprocess(img, channels) for img in data]
     
     return data
 
 
-def _check_mean_sub_values(value, channels):
-    """
-        Checks if mean subtraction values are valid based on the number of channels
-        'value' must be a tuple of dimensions = number of channels
-    Returns boolean:
-        True -> Expression is valid
-        False -> Expression is invalid
-    """
-    if value is None:
-        raise ValueError('[ERROR] Value(s) specified is of NoneType()')
-    
-    if type(value) is not tuple:
-        # If not a tuple, we convert it to one
-        try:
-            value = tuple(value)
-        except TypeError:
-            value = tuple([value])
-    
-    if channels not in [1,3]:
-        raise ValueError('[ERROR] Number of channels must be either 1 (Grayscale) or 3 (RGB/BGR)')
-
-    if len(value) not in [1,3]:
-        raise ValueError('[ERROR] Tuple length must be either 1 (subtraction over the entire image) or 3 (per channel subtraction)', value)
-    
-    if len(value) == channels:
-        return True 
-
-    else:
-        raise ValueError(f'[ERROR] Expected a tuple of dimension {channels}', value) 
\ No newline at end of file
+__all__ = [
+    'MeanProcess',
+    'compute_mean',
+    'compute_mean_from_dir',
+    'subtract_mean',
+]
\ No newline at end of file
