@@ -1,8 +1,14 @@
-# Author: Jason Dsouza
-# Github: http://www.github.com/jasmcaus
+# Copyright 2020 The Caer Authors. All Rights Reserved.
+#
+# Licensed under the MIT License (see LICENSE);
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at <https://opensource.org/licenses/MIT>
+#
+# ==============================================================================
+
+
+from .filevideostream import FileVideoStream
 
-# Importing the necessary packages
-from .file_videostream import FileVideoStream
 
 # Using the FileVideoStream class as it can handle both live as well as pre-existing videos
 
@@ -29,4 +35,9 @@ class VideoStream():
         return self.video_stream.get_fps()
         
     def release(self):
-        self.video_stream.release()
\ No newline at end of file
+        self.video_stream.release()
+
+
+__all__ = [
+    'VideoStream'
+]
\ No newline at end of file
