@@ -1,7 +1,15 @@
-# Author: Jason Dsouza
-# Github: http://www.github.com/jasmcaus
+# Copyright 2020 The Caer Authors. All Rights Reserved.
+#
+# Licensed under the MIT License (see LICENSE);
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at <https://opensource.org/licenses/MIT>
+#
+# ==============================================================================
+
+""" 
+Provides visualization-specific functions 
+"""
 
-""" Provides visualization-specific functions """
 
 def hex_to_rgb(x):
     """
@@ -31,4 +39,10 @@ def draw_rectangle(draw, coordinates, color, width=1, fill=30):
         if i == 0:
             draw.rectangle(coords, fill=fill, outline=outline)
         else:
-            draw.rectangle(coords, outline=outline)
\ No newline at end of file
+            draw.rectangle(coords, outline=outline)
+
+
+__all__ = [
+    'hex_to_rgb',
+    'draw_rectangle'
+]
\ No newline at end of file
